Theory and background discussions
=================================

The documents in this section provide discusssions that let to the development of the standard evaluator.

.. toctree::
   :maxdepth: 1

   need_for_explicit_inputs_output_def
   